#
# spec file for package python-pymisp
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-pymisp
Version:        2.4.123
Release:        bp153.1.18
Summary:        Python API for MISP
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/MISP/PyMISP
Source0:        https://github.com/MISP/PyMISP/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# github tarball misses the misp-objects subproject data
Source1:        https://github.com/MISP/misp-objects/archive/7ef9a2ba56efc6553a720d6df27c9ee547e24242.tar.gz#/misp-objects.tar.gz
# pypi tarball missing some files: https://github.com/MISP/PyMISP/issues/554
#Source:         https://files.pythonhosted.org/packages/source/p/pymisp/pymisp-%%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jsonschema
Requires:       python-python-dateutil
Requires:       python-requests
Recommends:     %{name}-doc
Recommends:     python-magic
Suggests:       python-pydeep
BuildArch:      noarch
# SECTION tests
BuildRequires:  %{python_module Deprecated}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module python-magic}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module requests}
BuildRequires:  python2-cachetools
BuildRequires:  python2-enum34
BuildRequires:  python2-functools32
# /SECTION
# SECTION docs
BuildRequires:  python3-CommonMark
BuildRequires:  python3-Sphinx
BuildRequires:  python3-recommonmark
BuildRequires:  python3-sphinx-autodoc-typehints
# /SECTION
%ifpython2
Requires:       python2-cachetools
Requires:       python2-enum34
Requires:       python2-functools32
%endif
Requires:       python-Deprecated
%python_subpackages

%package -n %{name}-doc
Summary:        Examples and Documentation for %{name}
Group:          Documentation/HTML

%description
PyMISP is a Python library to access MISP platforms via their REST API.

PyMISP allows you to fetch events, add or update events/attributes, add or update samples or search for attributes.

%description -n %{name}-doc
Examples and HTML documentation for %{name}.

%prep
%setup -q -n PyMISP-%{version}
#%%setup -q -n pymisp-%%{version}
%setup -T -D -b 1 -n PyMISP-%{version}
mv ../misp-objects-*/* pymisp/data/misp-objects/
find pymisp examples -name "*.py" -type f -exec sed -i '1s/^#!.*//' '{}' \+

%build
%python_build
pushd docs
export LANG=en_US.UTF-8
make %{?_smp_mflags} html
rm build/html/.buildinfo
popd

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}}

%check
export LANG=en_US.UTF-8
%python_exec setup.py test

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%files -n %{name}-doc
%doc examples docs/build/html

%changelog
* Tue Mar 17 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- set UTF-8 encoding for test, fixes Leap 15.1 buildc
* Sun Mar 15 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- change source URL to github, as the pypi archive misses some files.
- add misp-objects source as github archive misses it.
- update to version 2.4.123:
  - New
  - Add import script for dxy data. [Raphaël Vinot]
  - Csse covid19 daily report importer. [Raphaël Vinot]
  - Changes
  - Bump version. [Raphaël Vinot]
  - Bump changelog. [Raphaël Vinot]
  - Bump dependencies. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - JSON files are UTF8. [Raphaël Vinot]
    Bump dev deps, update comment
  - Add tag, set distribution, add file and source (CSSE importer)
    [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
- update to version 2.4.122:
  - New
  - Add uuid by default in MISPEvent, add F/L seen in feed output.
    [Raphaël Vinot]
  - Admin script to setup a sync server. [Raphaël Vinot]
  - Add feed generation example in notebook. [Raphaël Vinot]
  - Changes
  - Bump changelog. [Raphaël Vinot]
  - Comments were still referencing pipenv. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Bump changelog. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Bump dependencies. [Raphaël Vinot]
  - Bump dep. [Raphaël Vinot]
  - Fix typo in readme. [Raphaël Vinot]
  - Use bionic on travis. [Raphaël Vinot]
  - Add poetry support. [Raphaël Vinot]
  - Fix
  - Test cases & template version. [Raphaël Vinot]
  - Mypy, more typing. [Raphaël Vinot]
  - Do not skip data in add_attribute methods. [Raphaël Vinot]
  - Remove references to the old API. [Raphaël Vinot]
  - Other
  - Use poetry everywhere, fix readme. [Raphaël Vinot]
- update to version 2.4.121.1:
  - Changes
  - Bump changelog. [Raphaël Vinot]
  - Bump objects. [Raphaël Vinot]
  - Bump changelog. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - Fix
  - Make lief optional again. [Raphaël Vinot]
    fix #538
* Sat Feb  8 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.121.1:
  - Fix
  - Make lief optional again. [Raphaël Vinot]
    fix #538
- remove fix-tests-template-version.patch, merged upstream
* Thu Feb  6 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.121:
  - New
  - Add includeDecayScore to rest search. [VVX7]
  - Support for first_seen/last_seen. [Raphaël Vinot]
    Cleaner import of datetime
  - [attributes] chrome-extension-id added. [Alexandre Dulaunoy]
  - Changes
  - Do not install neo by default. [Raphaël Vinot]
  - Bump objects. [Raphaël Vinot]
  - More flexible when an event is in a weird state. [Raphaël Vinot]
  - Str to int, properly load SharingGroup. [Raphaël Vinot]
    Fix #535
  - Bump deps, add pep8 test. [Raphaël Vinot]
  - Bump objects. [Raphaël Vinot]
  - Support dict in tag/untag. [Raphaël Vinot]
  - Test update last seen. [Raphaël Vinot]
  - Add test cases in feed. [Raphaël Vinot]
  - Add test cases. [Raphaël Vinot]
  - Normalize to_datetime conversion. [Raphaël Vinot]
  - Trustar example uses objects. [Raphaël Vinot]
  - Add lief in the generic requirements. [Raphaël Vinot]
  - Refactorize typing, validate. [Raphaël Vinot]
  - Fix
  - Issue with readme. [Raphaël Vinot]
  - Remove debugging. [Raphaël Vinot]
  - [*-seen] Consider that `-` can also be in the date component while
    parsing. [mokaddem]
  - First seen was after last seen, trigerring the exception. [Raphaël
    Vinot]
  - Tests failing if local tz was not CET. [Raphaël Vinot]
  - Syntax and typos. [Raphaël Vinot]
  - Bugs introduced by last commit. [Raphaël Vinot]
  - Other
  - Doc: fix Search-FullOverview.ipynb code example. [Bernhard E. Reiter]
  - Chore: delete old examples. [Manabu Niseki]
    Delete examples which use deprecated/deleted methods
  - Scrape trustar intel platform reports and create misp events.
    [th3jiv3r]
  - Configuration for trustar integration. [th3jiv3r]
  - Fixed trailing lines. [turtlefac3]
  - Fixed trailing lines. [turtlefac3]
  - Custom integration written in python to scrape Proofpoint VAP API for
    metrics of top Very Attacked Persons and create MISP events.
    [turtlefac3]
  - Fix typos on FullOverview.ipynb. [Bernhard E. Reiter]
* Sat Jan 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- drop python2, not supported anymore upstream
- add fix-tests-template-version.patch from upstream commit to fix tests
- update to version 2.4.120:
  - New
  - [attribute type] kusto-query attribute type. [Alexandre Dulaunoy]
    Kusto query is the query language for the Kusto services in Azure used
    to search large dataset. It's used in Windows Defender ATP Hunting-Queries
    and also Azure Sentinel (Cloud-native SIEM).
  - Remove python < 3.6 support. [Raphaël Vinot]
  - Changes
  - Bump version. [Raphaël Vinot]
  - Bump Changelog. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Bump dependencies, add debug. [Raphaël Vinot]
  - Upate dummy events creator. [Raphaël Vinot]
  - Add tests on more version of Python. [Raphaël Vinot]
  - Search with the STIX output returns a json STIX. [Raphaël Vinot]
    Was XML before.
  - Bump dependencies. [Raphaël Vinot]
  - Add more typing information. [Raphaël Vinot]
  - Add typing markup. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Bump Dependencies. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Fix
  - Add missing variable in dummy creator. [Raphaël Vinot]
  - Et2misp was python2 only. [Raphaël Vinot]
  - Feed generator was broken. [Raphaël Vinot]
    Fix #506
  - Event without hashable attribute. [Raphaël Vinot]
    Related #506
  - Other
  - Update api.py. [AaronK]
    minor typo, can;t help it noticing those. sorry,
  - Fixed TODO, added quarantineFolder/quarantineRule from
    messagesBlocked, added some error handling to prevent empty attributes
    from trying to be added. [th3jiv3r]
  - Scrape proofpoint tap api for messages blocked/delivered & clicks
    blocked/permitted  and create misp events. [th3jiv3r]
  - Add variable for proofpoint tap api auth. [th3jiv3r]
  - Update README.md. [AaronK]
    minor typo
  - Define the number of entries to output. [AndreC10002]
    Allow for defining in the settings.py file the number of entries to output
  - Update generate.py. [AndreC10002]
  - Cleanup of code and 'quick-n-dirty' sanitizing of tags. [Koen Van
    Impe]
  - Sync. [Koen Van Impe]
  - Update README.md. [Raphaël Vinot]
* Wed Jan  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.119.1:
- New
  - URLObject (requires pyfaup) [Raphaël Vinot]
- Changes
  - Version bump. [Raphaël Vinot]
  - Bump test files. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Debug travis error message. [Raphaël Vinot]
  - [types] eppn type added. [Alexandre Dulaunoy]
  - Fix typo. [Raphaël Vinot]
  - Move scrippsco2 feed generator to a sub directory. [Raphaël Vinot]
  - Update documentation. [Raphaël Vinot]
    Fix #396
  - Bump objects. [Raphaël Vinot]
- Fix
  - Properly test custom objects. [Raphaël Vinot]
  - Adding a sighting takes a little bit of time. [Raphaël Vinot]
  - Test case on reference. [Raphaël Vinot]
  - Add missing fields to event & attribute for the feed output. [Raphaël
    Vinot]
  - Make sure the publish timestamp is bumped on update. [Raphaël Vinot]
* Sun Dec 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.119:
  - Changes
  - Bump version. [Raphaël Vinot]
  - Bump dependencies. [Raphaël Vinot]
  - Fix
  - Bump lief to 0.10.1. [Raphaël Vinot]
  - Update tests. [Raphaël Vinot]
  - Raise PyMISPError instead of Exception. [Raphaël Vinot]
  - Rename feed_meta_generator so it clearly fails with python<3.6.
    [Raphaël Vinot]
* Tue Nov 26 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.117.3:
- New
  - Script to generate the metadata of a feed out of a directory. [Raphaël
    Vinot]
  - Add to_feed export to MISPEvent. [Raphaël Vinot]
  - Validate object templates. [Raphaël Vinot]
    fix https://github.com/MISP/misp-objects/issues/199
  - Test cases for restricted tags. [Raphaël Vinot]
    Fix #483
  - Get Database Schema Diagnostic. [Raphaël Vinot]
    Fix #492
- Changes
  - Bump version. [Raphaël Vinot]
  - Bump dependencies. [Raphaël Vinot]
  - Require stable version of lief again. [Raphaël Vinot]
  - Few more improvements on the feed export. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Make the feed generator more generic. [Raphaël Vinot]
  - Use New version of PyMISP in the feed generator. [Raphaël Vinot]
  - Bump misp-object. [Raphaël Vinot]
  - Allow to sort and indent the json output for objects. [Raphaël Vinot]
  - Bump objects. [Raphaël Vinot]
  - Bump dependencies. [Raphaël Vinot]
  - [test] feed test updated as botvrij is now TLS by default. [Alexandre
    Dulaunoy]
- Fix
  - Improve stability of feed output. [Raphaël Vinot]
  - Do not unitialize the uuid in MISPEvent. [Raphaël Vinot]
  - Bump url template version in test cases. [Raphaël Vinot]
  - Python 2.7 tests. [Raphaël Vinot]
  - Print the full json blob in debug mode. [Raphaël Vinot]
    Related https://github.com/MISP/PyMISP/issues/462
- Other
  - Cch: Bump misp-objects. [Raphaël Vinot]
- update to version 2.4.117.2:
- Changes
  - Bump changelog. [Raphaël Vinot]
- Fix
  - Avoid exception on legacy MISP. [Raphaël Vinot]
- update to version 2.4.117.1:
- New
  - Add support for UserSettings. [Raphaël Vinot]
- Changes
  - Bump changelog. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Use default category from template. [Raphaël Vinot]
    Fix #477
  - Skip usersettings tests when emails are disabled. [Raphaël Vinot]
- Fix
  - [examples] typo uuid. [Jean-Louis Huynen]
    give me a hoodie.
  - Prevents exception when lief is not installed. [Christophe Vandeplas]
  - Python <3.4 should work again.... [Raphaël Vinot]
    Fix #482
  - Remote_describe_types response was invalid. [Raphaël Vinot]
  - Missing file in last commit. [Raphaël Vinot]
  - Remove overwrite of remote_describe_types. [Raphaël Vinot]
- Other
  - Added example for checking sync servers. [wotschel]
  - Corrected docstring. [Shortfinga]
  - Include to_ids and replace newlines in title. [Koen Van Impe]
  - Update aping.py. [ater49]
    Just fixing a typo
  - Remove unused MISPFileCache from PyMISP class. [Marc Hoersken]
- update to version 2.4.117:
- New
  - Better handling of delete(d) attributes. [Raphaël Vinot]
  * Hard delete on attribute
  * Get the deleted attributes within an event
- Changes
  - Bump changelog. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - Test if json exists in cached method. [Raphaël Vinot]
  - Decode datetime without dateutils if possible. [Raphaël Vinot]
  - Add support for rapidjson, refactoring and code cleanup. [Raphaël
    Vinot]
  - Cleanups. [Raphaël Vinot]
  - Cleanups and improvements. [Raphaël Vinot]
  - [types] updated to the latest version. [Christophe Vandeplas]
    now using the gen_misp_types_categories using jq
  - [describeTypes] updated to the latest version. [Alexandre Dulaunoy]
  - Bump dependencies. [Raphaël Vinot]
  - Add missing return formats in restsearch, bump objects. [Raphaël
    Vinot]
  - [misp-objects] updated to the latest version. [Alexandre Dulaunoy]
  - Update search examples. [Raphaël Vinot]
  - Update main notebook. [Raphaël Vinot]
  - [test] remove attribute field which was not foreseen in 2.4 branch.
    [Alexandre Dulaunoy]
  - Fix travis tests due to sighting_timestamp. [Raphaël Vinot]
  - Use default for warnings. [Raphaël Vinot]
    fix: #453
  - Dump dependencies, update tests. [Raphaël Vinot]
  - Bump readme. [Raphaël Vinot]
  - Update upload malware/attachment example script. [Raphaël Vinot]
    Fix #447
    Make data at attibute level more generic with getter/setter methods
- Fix
  - [Python2] Use LRU cache decorator, fix call to describe_types in
    PyMISP. [Raphaël Vinot]
  - Python2 SyntaxError... [Raphaël Vinot]
  - Objects helpers were broken, do not overwrite describe_types. [Raphaël
    Vinot]
  - Support for legacy python versions. [Raphaël Vinot]
    90 days and counting, folks.
  - Cache object templates at AbstractMISP level. [Raphaël Vinot]
    Related #468 and  #471
  - Cache describeTypes at AbstractMISP level. [Raphaël Vinot]
  - Big speed improvment when loading MISPEvent. [Raphaël Vinot]
    1. `properties` is a list comprehension
    2. Massively reduce the amount of calls to `properties`
  - Python 2.7 support. [Raphaël Vinot]
    I want a cookie.
- Other
  - Use classmethod instead of staticmethod and avoid hard-coded
    reference. [Marc Hoersken]
  - Cache JSON definitions in memory LFU cache provided by cachetools.
    [Marc Hoersken]
  - Path and modified time of JSON file are used as the cache key
  - Global state is hidden away inside a root-class for re-use
  - Maximum size is 150 considering the number of JSON definitions
    During my tests the memory usage of the test suites was halved.
  - Fix mixed whitespace in the travis helper script files. [Marc
    Hoersken]
  - Remove explicit clonce as the viper-test-files are now a Git
    submodule. [Marc Hoersken]
  - Add viper-test-files repository as Git submodule. [Marc Hoersken]
  - Update .gitignore to exclude files produced during tests. [Marc
    Hoersken]
  - Code cleanup. [Koen Van Impe]
  - Update type and code cleanup. [Koen Van Impe]
  - List all the sightings - show_sightings.py. [Koen Van Impe]
  - Disable to_ids based on false positive sightings reporting. [Koen Van
    Impe]
  - Adds support to add local tags. [Antoine Cailliau]
    Requires https://github.com/MISP/MISP/pull/5215 to be merged first.
  - Minor grammar errors. [Miroslav Stampar]
  - Make client_certs out of the box friendly. [Campbell McKenzie]
- update to version 2.4.114:
- New
  - [Community] Request access. [Raphaël Vinot]
  - Initial support for communities. [Raphaël Vinot]
  - Contact event reporter. [Raphaël Vinot]
  - Delegate Event. [Raphaël Vinot]
    And more test cases
- Changes
  - Bump Changelog. [Raphaël Vinot]
  - Bump Changelog. [Raphaël Vinot]
  - Temp disable tests for request_community_access. [Raphaël Vinot]
  - Disable test for now. [Raphaël Vinot]
  - Bump Changelog. [Raphaël Vinot]
  - Bump Dependencies. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Re-enable a few test cases. [Raphaël Vinot]
  - Make sure delegation is enabled while testing. [Raphaël Vinot]
  - [tests] Check the type of the response. [Raphaël Vinot]
  - New local key in Org/Orgc. [Raphaël Vinot]
  - [tests] Do not run in fast mode by default. [Raphaël Vinot]
  - Better handling of sightings. [Raphaël Vinot]
  - [Travis] Add more debug. [Raphaël Vinot]
  - Add test related to travis. [Raphaël Vinot]
- Fix
  - Event delegation was incorrect. [Raphaël Vinot]
  - Automatically skip empty string in add_attribute at object level.
    [Raphaël Vinot]
    Fix #439
    Re-enable test cases.
  - [Travis] User cannot create tag, Travis was right. [Raphaël Vinot]
  - Invalid tests in last commit. [Raphaël Vinot]
  - [Travis] Slight changes to help debug on Travis. [Raphaël Vinot]
- Other
  - Bump Changelog. [Raphaël Vinot]
- update to version 2.4.113:
- New
  - Helpers & testcases for syncing. [Raphaël Vinot]
  - Preliminaty setup for testing syncing. [Raphaël Vinot]
  - Add few tests for admin tasks. [Raphaël Vinot]
  - Update MISP, test sync server. [Raphaël Vinot]
  - Properly support attribute/add of multiple attributes (2.4.113+)
    [Raphaël Vinot]
- Changes
  - Bump Changelog. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - Improve test cases. [Raphaël Vinot]
  - Update and improve live testing. [Raphaël Vinot]
  - Add tests cases for sync, bump describeTypes. [Raphaël Vinot]
  - Return empty list instead of None. [Pierre-Jean Grenier]
    In all cases but one, the 3rd returned object is a (potentially empty) list.
  - Some more code cleanup. [Raphaël Vinot]
  - Code cleanup. [Raphaël Vinot]
  - Enable more tests. [Raphaël Vinot]
  - #4891 was fixed. [Raphaël Vinot]
  - Bump describeTypes. [Raphaël Vinot]
- Fix
  - Fallback to propose attribute update. [Raphaël Vinot]
  - Properly __repr__ MISPUser. [Raphaël Vinot]
  - Move __not_jsonable *inside* the __init__ [Raphaël Vinot]
    Turns out, if you modify a variable defined outside the __init__,
    every instances (and inherited classes) of that class will be impacted by it.
  - Exception when posting multiple attributes on attributes/add. [Raphaël
    Vinot]
    Fix #433
    Few cleanups in code.
- Other
  - Include date_from & date_to in subject and report content. [Koen Van
    Impe]
  - Allow statistics date_from date_to. [Koen Van Impe]
  - date_from + date_to
  - move misp object creation after argument parser
  - Allow to supply mail options as arguments on command line. [Koen Van
    Impe]
  - Fix stats_report example to use ExpandedPyMISP. [Maxime Thiebaut]
    The stats_report example relied on deprecated functions making it crash.
    This has been fixed by upgrading to ExpandedPyMISP. Further checks have
    been introduced to ensure used dictionnary keys do exist as the example
    also crashed on clean MISP instances due to empty responses.
* Sat Aug  3 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.112:
- New
  - [Search] Add a few new options in rest search. [Raphaël Vinot]
  - Allow to change the template on an object on-the-fly. [Raphaël Vinot]
  - [example] Script to load datasets from Scripps CO2. [Raphaël Vinot]
  - Get_objects_by_name in MISPEvent. [Raphaël Vinot]
    new: Convert datetime objects to python datetime.
- Changes
  - Bump Changelog. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - [tests] Few improvements. [Raphaël Vinot]
  - [tests] Add new test cases. [Raphaël Vinot]
  - Rename relationship included-in -> includes. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - [deps] Bump. [Raphaël Vinot]
  - [examples] pythonify properly when needed. [Raphaël Vinot]
  - [tests] Toggle pythonify in create_massive_dummy_events. [Raphaël
    Vinot]
- Fix
  - Inconsistency in MISPEvent, reenable tests. [Raphaël Vinot]
  - Some test cases need more love. [Raphaël Vinot]
  - PyTaxonomies is not compatible with python<3.6. [Raphaël Vinot]
  - Rename filename. [Raphaël Vinot]
  - [deprecation] Wrong deprecation message. [Raphaël Vinot]
    Also, deprecated method was broken.
    Fix #424
- Other
  - Add: New attribute type weakness. [chrisr3d]
  - Fix missing f in f-string. [Paal Braathen]
  - Wrong variable. [Georges Toth]
  - Remove unused line. [kovacsbalu]
  - Fix tag help text Minor pycodestyle. [kovacsbalu]
* Thu Jul 25 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- add missing dependency python-Deprecated
* Thu Jul 25 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.111.2:
- New
  - [Sightings] Delete method. [Raphaël Vinot]
    Fix #230
  - [tests] non-exportable tags. [Raphaël Vinot]
- Changes
  - Bump verison. [Raphaël Vinot]
  - Make pythonify=False default everywhere. [Raphaël Vinot]
    Add a method to toggle pythonify globally
  - [tests] Update stats. [Raphaël Vinot]
  - [tests] Remove travis exceptions. [Raphaël Vinot]
- Fix
  - [tests] Path to test file. [Raphaël Vinot]
    Fix #423
  - [objects] Allow the value of an attribute to be 0. [Raphaël Vinot]
  - [tests] Disable one of the test cases for now. [Raphaël Vinot]
  - [tests] By default, the workflow taxonomy isn't enabled. [Raphaël
    Vinot]
  - Properly handle fallbacks add/update/delete attributes. [Raphaël
    Vinot]
  - [add_attribute] Only create a proposal when needed. [Raphaël Vinot]
- Other
  - Fix for issue 420. [github-pba]
- update to version 2.4.111.1:
- New
  - Add option to locally expand malware samples with LIEF. [Raphaël
    Vinot]
- Changes
  - Bump Changelog. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - Bump misp-objects. [Raphaël Vinot]
  - Remove legacy tests. [Raphaël Vinot]
  - Improve deprecation message on PyMISP. [Raphaël Vinot]
  - [describeTypes] updated to add community-id. [Alexandre Dulaunoy]
  - Bump examples to python3. [Raphaël Vinot]
  - Reorganise ExpandedPyMISP methods, normalise the parameters. [Raphaël
    Vinot]
  - Deprecate everything in PyMISP. [Raphaël Vinot]
- Fix
  - Python < 3.6 support. [Raphaël Vinot]
- Other
  - Create statistical reports for MISP. [Koen Van Impe]
    PyMISP script to run every x-days to get an overview of new
    events/attributes ; MISP-Galaxies ; MITRE ; Tags
    Output of report is on screen or sent via e-mail ; all stats attached
    as CSV
- update to version 2.4.111:
- New
  - Introduce ability to create a sharing group. [Tom King]
  - Allow to pass delimiter & quotechar to the CSV loader. [Raphaël Vinot]
  - [example] Added edit_organisation examples. [Steve Clement]
  - Method to POST a STIX file to MISP and create a new event. [Raphaël
    Vinot]
  - Object generator for ssh authorized_keys files. [Raphaël Vinot]
  - Allow custom user-agent. [Christophe Vandeplas]
- Changes
  - Bump changelog. [Raphaël Vinot]
  - Bump version. [Raphaël Vinot]
  - Bumb misp-objects. [Raphaël Vinot]
  - [tests] WTF upload_sample on travis. [Raphaël Vinot]
  - [tests] Add custom error message on upload_sample - fix last commit.
    [Raphaël Vinot]
  - [tests] Add custom error message on upload_sample. [Raphaël Vinot]
  - Remove roaming as it can't be set in this request. [Tom King]
  - Allow for deletion of security group. [Tom King]
  - Bump dependencies. [Raphaël Vinot]
  - [last] You can now paginate over multiple results in the last example
    command. [Alexandre Dulaunoy]
    You can do stuff like this:
    python3 last.py  -l 48h  -m 10 -p 2  | jq .[].Event.info
    which means the last 10 events on second page which are between a
    time range of 0 and 48 hours.
  - [tests] now deleted flag is returning only the deleted values (to be
    consistent) [Alexandre Dulaunoy]
  - [misp-objects] updated to the latest version. [Alexandre Dulaunoy]
  - Bump deps (lief 0.10 dev) [Raphaël Vinot]
  - Use pydeep from pypi, add test. [Raphaël Vinot]
  - Bump dependencies. [Raphaël Vinot]
  - Bump dependencies. [Raphaël Vinot]
  - Bump Pipfile for python 3.7. [Raphaël Vinot]
- Fix
  - Skip attribute in object when value is empty, skip empty objects.
    [Raphaël Vinot]
  - [perms] Added try/except for various permission conditions, also
    create the output dir if not exist fix: [try/except] Catch Ctrl-c
    keyboard interrupt fix: [style] isort imports. [Steve Clement]
  - [direct_call] Allows the response type to be something else than a
    JSON (e.g. csv). [mokaddem]
  - [feed generator] Added missing fields. [iglocska]
  - Properly fix deprecation warning. [Raphaël Vinot]
    fix #390
  - Travis & python2. [Raphaël Vinot]
  - Last commit foobar. [Raphaël Vinot]
  - Install lief on python < 3.7 with pipenv. [Raphaël Vinot]
- Other
  - [openioc] changed default mapping for
    RouteEntryItem/Destination/string. [0x3c7]
  - [openioc] Changed mapping for RouteEntryItem/Destination/string to
    domain instead of url because UrlHistoryItem/URL is mostly used for
    urls. [0x3c7]
  - Fixes other mapping to other types. [0x3c7]
  - [openioc] Allow the use of types in openioc content tags. [0x3c7]
  - Sync sightings between MISP servers. [Koen Van Impe]
    Sync sightings between MISP servers
    Sync from multiple clients to one authoritative MISP instance.
    To be run from cron
    (blog docu coming)
  - Added includeWarninglistHits as a possible filter for the event level
    restsearch. [Jeroen Pinoy]
  - Resolve issue with change_sharing_group which do not update event
    successfully. [hrifflet]
  - Use misp_verifycert flag. [Koen Van Impe]
  - Take 'to_ids' setting in account and PEP8 checks. [Koen Van Impe]
  - Include check if 'to_ids' is included in the data returned from the
    import module
  - PEP8 checks
  - Automation script that links vmray_submit and vmray_import. [Koen Van
    Impe]
    Import finished VMRay tasks ; add attributes to event
    Makes use of the 'incomplete' workflow taxonomy
    Needs to be put in a cronjob to run in the background
  - Update PyMISP_tutorial.ipynb. [Carlos Borges]
    The function to collect event_id and put it into a list isn't looking into each MISPAttribute.
    Just updated the script to look it.
* Fri May  3 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.106:
  - New
  - Test cases for attributes and proposals.
  - Improve python3.6+ lib.
  - Add_attributes method in MISPObject (for multiple attributes)
  - Method to set the default role.
  - Default to "me" in the get_user method, update ExpandedPyMISP.
    Fix #377
  - Add get_object to ExpandedPyMISP.
    Fix #372
  - Test cases for CSV loader, add cleaner methods in ExpandedPyMISP.
  - Add CSV loader.
    Fix #376
  - Helper to create MISP Objects for regcheck.org.uk.
  - Test for ACLs in testlive.
  - Test for manual calls to add_object and add_object_reference.
  - Test update object in event.
  - Changes
  - Add python 3.7 support for pipenv users.
  - Allow to pass a eml as string to EmailObject.
  - Bump dependencies.
    Fix CVE-2019-11324 (urllib3)
  - Allow to pass an AbstractMISP to add_reference.
    Fix #379
  - Rework notebooks.
  - Display an error on failure in testlive.
  - Add tests for disable_tag.
  - Reorganize some tests.
  - Orders of tests in make_bool.
  - Initial set of refactoring on PDF generator.
  - Add i8n for pdfexport, without all the fonts in the main repo.
  - Fix
  - Build on readthedocs.
  - [typo] Fixed a small typo I noticed in the docs.
  - Add missing files for testing (CSV loader)
  - Properly test query ACLs.
  - Update all json submodules at one place in testlive.
  - Disable some tests for the run on travis.
  - [exportpdf] Doc update. [Falconieri]
  - [exportpdf] Coding Style. [Falconieri]
  - Improper handling of to_ids passed as integer in MISPEvent.
    Fix #364
  - Do not fail when importing the reportlab file.
  - PDF Export requires python 3.6+.
  - Do not run PDF Export tests on python < 3.6.
  - [exportpdf] Custom path for fonts and font package.
  - Allow to use global variables HTTP_PROXY and HTTPS_PROXY again.
    Fix #365
  - Slight changes in new .change_disable_correlation method.
  - Get_object_template_id was broken. Add test case.
    Fix #361
  - Other
  - New Add test for ASNObject.
  - Update README.md.
    Added number of monthly PyPi downloads
  - Add: [exportpdf] documentation added about exportPDF.
  - Fix for "'NoneType' object has no attribute 'setdefault'"
  - Fix a type on function name.
  - Add new function
    PyMISP.change_disablecorrelation(attribute_uuid,disable_correlation)
    to be able to enable/disable correlation on attributes.
* Sat Mar 23 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- New requirement python3-sphinx-autodoc-typehints for docs.
* Sat Mar 16 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- run spec-cleaner
- update to version 2.4.103:
  - New
  - Add auth parameter to pass to python-requests.
  - Add readthedocs config.
  - Changes
  - [jupyter] remove all the response key (as response is removing it)
  - Enforce strict in object testing to ease debugging.
  - [pipenv] Pipfile.lock generated.
  - [exportpdf] BIG refactoring. Classes, comments, Galaxy starting.
  - [exportPDF] add basic handling of clusters.
  - [exportpdf] Add metadata, bugfixes cases (too long values,
    sanitization), links to misp instances.
  - Add sphinx-autodoc-typehints.
  - Use version 2 of readthedoc config file.
  - [doc] add a reference to the Jupyter Notebook.
  - Remove dependency on six.
  - Fix
  - [exportpdf] fix empty object/attribute/galaxy bugs.
  - [exportpdf] Add suggestions (UX)
  - [exportpdf] switch page size to A4.
  - [exportpdf] switch page size to A4.
  - Hopefully last fix for python 2.7 & reportlab.
  - Properly pass the auth parameter to the request.
  - Properly catch error if reportlab isn't installed.
  - Make sure install works even without reportlab installed.
  - URLJoin condition for double quotes. [Hannah Ward]
  - Do not override sub-path from root URL. [Hannah Ward]
  - [reportlab] Galaxies and Clusters printing.
  - [reportlab] Clusters added. Still UX to perform.
  - [reportlab] working clusters and galaxies. Not nice however.
  - [exportPDF] Adding facultative text description, sightings, tests
    cases.
  - [exportpdf] Add Object date.
  - [exportpdf] Double property printing error fixed.
  - [exportpdf] Refactoring, nicer code.
  - [pdfexport] Fix tests paths, dependency in pipfile, imports, and
    'file' name overwrite in test function.
  - Copy event dictionary when creating a MISPEvent.
    Fix #321
  - Wrong documentation on PyMISP.search_sightings.
    Fix #336
  - Typo in sphinx config.
  - Fix dependencies for py2.
  - Properly inform user when they try to run the live tests on old
    systems.
    Fix #329
  - Other
  - Add : [exportpdf] Objects handling, tests cases, test files.
  - Add: [exportpdf] Handling pictures embedded as attributes.
  - Add : [exportpdf] Picture management, manual.
  - Fix & add: [exportpdf] Add metadata, fix special cases (too long
    values, sanitization)
  - Add: exportpdf tool working.
  - General improvement : deisgn, exhaustiviness of mispEvent values
    displayed, good pratice concerning paragraphe/table made.
  - Update with table basics.
  - Structure of the improvements OK : test file, test folder, report
    generator.
  - Search function fix to comply new version of MISP.
* Sun Feb  3 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.102:
  - New
  - Add test cases for stix export.
  - Changes
  - [datamodel] new anonymised type added.
  - [data] types updated to include the new zeek type.
  - Other
  - Check if IOC values are in warninglist.
- update to version 2.4.101:
  - New
  - Add missing test case for NOT on attribute level, update Pipfile.
  - Add support for unix timestamp in set_date.
    fix #302
  - Add test for references when adding/updating a full event.
  - [usersStats] Possibility to fetch users/statistics data for all
    context (usage, org, tags, ...)
  - Changes
  - Force to_ids to be a boolean, as MISP is expecting.
    fix #320
  - Add support for sharing group filter for search_index.
  - Support for Payload Delivery > Other attribute as PyMISP function.
  - Add Pipfile config.
  - [data] fix describeTypes.
  - [data] new types added (hassh-md5 and hasshserver-md5)
  - Bump misp-objects.
  - [misp-objects] templates updated to the latest version.
  - [data] describeTypes updated (grabbed from MISP HEAD)
  - [data] ja3-fingerprint-md5 type added.
  - [test] set a default distribution for massive event creation.
  - [data] describeTypes.json updated to the latest version.
  - More flexibility when loading an object from python dict.
  - Pass all parameters to the search API.
  - Remove compat for MISP 2.4.52, cleanup.
  - Set verifycert to false in tests.
  - [tests] Added verifycert option in case of using self-signed cert.
  - Fix
  - Remove jupyter & ipython from dev install so it works with python2.
  - Wrong variable name in MISPEvent.
  - Documentation error fix #278.
  - Attempt to fix memory footprint in MISPAttribute.
  - Still support simple event dict content.
  - Don't modify event passed to the add_attribute methods.
    fix #321
  - The wrong class name was used when there is an error at Event
    creation.
  - Use new API in get_csv.py.
    Fix #314
  - Test case was broken.
  - Create massive event using ExpandedPyMISP.
  - Error vs errors key.
  - Typo.
  - Get_object_template_id.
  - Other
  - Update pymisp tutorial.
    Extract the "response" field from the json result returned by misp.search_index
  - Sort describeTypes.json output.
    This is needed for the compatibility with the gen_misp_types_categories.py script. Data was sorted using the order_dict function of the gen_misp_types_categories script.
* Sun Jan 27 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.4.99:
  - New
  - Auto generate doc for PyMISPExpanded.
  - Search_index in ExpandedPyMISP, cleanup, update jupyter.
  - Add log search.
  - Add test for pushing an event to ZMQ.
  - Change_distribution method.
  - Add test cases for sightings, cleanup.
  - [example] Added sighting rest search example.
  - [sighting] Added support of sighting REST API.
  - Allow to pass csv to return_format in search.
  - Page/limit in search.
  - Changes
  - Add test cases for default distribution levels.
  - Include proposals in attributes search.
    Add includeProposals param to the search method
  - Update readme to document testing.
  - Fixes & update Jupyter.
  - [tuto] Update search.
  - Add a script to load the API key from the file system (training VM)
  - Add print in testlive to debug travis.
  - Fix
  - Auto generate doc for PyMISPExpanded.
  - Properly handle errors on event creation/update.
  - Test case.
  - Do not run the zmq test on travis.
  - Type of quick_filter.
  - Quick_filter was broken.
  - Properly initialize the config when jupyter runs on the VM.
  - Readme update + python3 + pep8.
    align python path to readme specifying python3
  - Feed-generator gitignore.
  - Test cases.
  - Other
  - Dded get_object & get_attribute.
  - Fix for last pymisp version.
  - Mention virtualenv.
    mide make sense for people who want to use it with virtualenv
  - Be more precise with the supported time indicators.
  - Fixed documentation bug.
  - Fixes date parameters for search_index() function.
  - Align examples on custom usage of misp_verifycert.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Oct 14 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- Remove fix-274.patch and fix-274-1.patch.
- update to version 2.4.96:
  - New
  - [freedFromRedis] try to create an object/attribute out of the incoming
    data even if not added with the helper.
  - Direct_call without data means GET.
  - Add direct call to just post data on a URL.
  - Update warninglists.
  - Toggle warning list, add test case.
  - Add lots of test cases, find lots of bugs.
  - Use new CSV interface, add test cases.
  - Changes
  - Allow to pass a json string to direct_call.
  - Update order parameters & doc.
  - Add an extra IP from the warninglists.
  - Fix
  - Prevent checking length on a integer.
  - Use proper dependency (enum34)
  - Other
  - Fixed leaked taxonomy tags problem.
  - Added some getters and setters for taxonomies, warninglists,
    noticelists and tags & documentation.
  - Add: Advanced Extraction to upload_sample.
  - Add: update noticelists and object templates.
  - Add: Add __eq__ to AbstractMISP.
    Allow to discard duplicate tags.
* Mon Sep 17 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- Add fix-274.patch and fix-274-1.patch to fix missing enum library (#274).
- update to version v2.4.95 (2018-09-06):
  - New
  - Add helpers for new server related APIs.
  Fix #266
  - Reworking the REST API (WiP)
  - Add Jupyter for search.
  - Changes
  - [data-model] updated describeTypes file.
  - Added email-header attribute.
  - Updated types/categories mapping.
  - Open all json files as bytes before loading in json.
  - [PyMISP] describeTypes.json updated to add XMR type.
  - Fix
  - Normalizing the outputs.
  - Jerry rig support for old python.
  - Format of the describeTypes.
  - [search.py] more example of query type added.
  - Properly validate the last-type search query.
  - Opening the json blobs as bytes was buggy.
  - Allow boolean parameters in search_index.
  - Typo in OpenIOC script.
  - Fix #237
  - Bad URL in get_attachment.
  - Fix #240
  - Improve error message in case the object template is unknown.
- update to version v2.4.93 (2018-07-01):
  - New
  - Add many comments in the jupyter notebook.
  - Return the new object in `add_object`
  - Add the ability to add Other attributes via the API.
  - Tuto for MISPEvent.
  - Load Org and Orgc as MISPOrganisation.
  - Related to #239
  - Changes
  - Moar jupyter.
  - Add few more calls.
  - Fix sample retrieval from new-style zips.
  - Raise an exception if the response is not in JSON.
- update to version v2.4.92.1 (2018-06-05):
  - Fix
  - Index out of range in add_object.
- update to version v2.4.92 (2018-06-05):
  - New
  - Add edit_object, simplify add_object.
  - Fix
  - Correct docstring of search method. [iso]
  - Response data type mismatch in _send_attributes()
  - Fix #206
  - Decoding issue.
* Thu May 10 2018 sebix+novell.com@sebix.at
- update to version 2.4.90.1:
  * New
  - Properly implement the Email object creator.
  * Changes
  - Normalize the RestResponse calls.
  * Fix
  - Properly get and decode the body of the email.
  - Provide the extension of the EML file to attach.
  - Properly handle attachments.
* Sun Apr 29 2018 sebix+novell.com@sebix.at
- update to version 2.4.90:
  * New
  - Add more feed management methods. Fix #221
  - Add update_attribute method.
  - Add event_timestamp to REST search. Fix #220
  - Add helper for Geolocation object.
  - Add helper for ASN object.
  - More flexibility in <something> -> datetime.
  - Add helper for DomainIP.
  - Add preliminary fail2ban object.
  * Changes
  - Add more examples.
  - Remove useless timestamp cleanup.
  - Make object helpers more generic, cleanup.
  - Update fail2ban helper & example.
  * Fix
  - Use the recommended approach to add an attribute.
  - Tests, new template version.
  - New key - extends_uuid.
  - Update test file accordingly to the default value.
  - Geolocation object filename.
  - Consider a timestamp < 30000000 as a date.
  - AbstractMISP.from_dict() do not accept positional argument.
  - Properly create fail2ban object.
  - Add Info field to the event.
  - Disable email object for python <3.6.
  * Other
  - Added missing field to feed generator.
  - Add the ability to add an Autonomous System(AS) via the API.
  - Changed shebang to python3.
  - Deleted remaining outputs.
  - First jupyter notebook tutorial (1 iterations)
  - Added change_analysis_status API.
  - Fix add_named_attribute regression, update add_named_attribute.py
    example.
  - Example of specifying special attribute type in your search: here yara
    attribute.
* Fri Mar 23 2018 sebix+novell.com@sebix.at
- update to 2.4.89:
  - Add email object generator.
  - Method to return an object by uuid.
  - Do not try to upload objects in case make_binary_objects fails. Realtime feed generator
  - Creation of the generator object which permit to easily add attributes and objects to daily events, stored as a MISP feed.
  - Added support of MISP Object.
  - Point to right anchor for client side certificates.
  - Add search on sighting.
  - Add attributes within objects as well, for tagging via value/id/uuid.
* Tue Feb 13 2018 sebix+novell.com@sebix.at
- update to version 2.4.87.1:
  - APIs to manage sharing groups. (#185)
  - ReturnMetaAttributes flag for freeTextImport API. (#188)
  - Encode string in _encode_file_to_upload.
  - Prevent unpublished events to be included in feed.
  Change default proposed config
- remove patch fix-Encode_string_in__encode_file_to_upload.patch, included upstream
* Tue Jan 30 2018 sebix+novell.com@sebix.at
- update to version 2.4.87:
  - Add bindings for Galaxies and Taxonimies.
  - Add bindings to PyMISPWarninglists.
  - Raise an exception when distribution is sharing group, but the ID is
  missing.
  - Allow to pass a directory with custom object templates.
  - Allow to pass value, UUID, or ID to a sighting.
  - Add_hashes was broken. (#174)
  - Add: Allow to fetch warninglists. (#180)
- Add fix-Encode_string_in__encode_file_to_upload.patch to fix encoding problem (#183)
* Fri Dec 22 2017 sebix+novell.com@sebix.at
- update to version 2.4.85:
  - Add last field to get_csv.
  - Validate attributes in attributes.setter.
  - Add get_attribute_tag method at MISPEvent level.
  Also add a MISPTag class for consistency.
  - Use new format for filtering.
  - Initialize default class parameters. (#155)
  - Fix MISPObject missing distribution and sharing_group_id.
  - fix MISPObject missing distribution concept
  - fix language typo paramaters => parameters
  - Include documentation and examples in source dist.
* Wed Dec 13 2017 sebix+novell.com@sebix.at
- update to version 2.4.84
  - Add methods to get taxonomy(ies)
  - Add method to get all the events modified in an interval.
  - Allow to pass a pseudofile to LIEF.
  - Correction for 'last' param. 'last' gives the latest events that
  have been published - add get_events_last_modified() this function
  returns the modified events based on timestamp.
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- update to version 2.4.83
  - Add get CSV method.
  - Allow to pass a proxy to query VT.
  - Do not get the event from the server before publishing if
  PyMISP.publish gets an ID.
  - Add a way to check if the ACL is up-to-date.
  - Add validators for describeTypes on the live instance.
  - Add new objects: MISPUser and MISPOrganisation.
  - Add a generic MISP object generator.
  - Allow to add multiple attribute of the same type.
  - Add fast publish method. Fix #86
* Fri Nov 10 2017 sebix+novell.com@sebix.at
- update to version 2.4.82
  - Proper debug system.
  - Changes
  - Small improvments in the logging system using python logging module.
  - Let load unknown object relations in known templates.
  - Allow to load non-malware ZIP files in MISP Event.
  - Properly pass the distribution when uploading a sample.
  - Other
  - Created add_generic_object.py.
- remove patch fix-offline-test.patch, included in upstream version
- shorten existing changelogs
* Thu Oct 26 2017 sebix+novell.com@sebix.at
- update to version 2.4.81.2
- update to version 2.4.81.1:
  - Allow to hard delete an attribute by ID.
  - Fixes
  - Improve dependencies listing. Partial fix for #110
  - Missing default category. Fix #119
- add fix-offline-test.patch to fix tests
* Mon Oct  9 2017 sebix+novell.com@sebix.at
- update to version 2.4.81
* Wed Oct  4 2017 sebix+novell.com@sebix.at
- update to version 2.4.80.1
  - Fix
  - Allow again to tag/delete unsaved attributes.
  - Import the openioc converter from tool again.
  - Other
  - Fixing #114 (MISPEvent.add_tag(tag) fails if inital event does not contain tag )
  - Formatted "Unknown MISP object" error message.
- removed fix-tests-pr-111.patch, merged upstream
* Wed Sep 20 2017 sebix+novell.com@sebix.at
- update to version 2.4.80
  - Allow to get the list of known types out of MISPEvent again.
  - Changed two fields in object references.
  - source_uuid => object_uuid
  - destination_uuid => referenced_uuid
  - Refactoring in order to load objects.
  - Add support for multiple entries of the same type in an object.
  - Add support for ELF and MachO objects.
- add fix-tests-pr-111.patch to skip an optional test depending on third party data
* Thu Sep  7 2017 sebix+novell.com@sebix.at
- update to version 2.4.79
- updated shebang fixes
* Wed Aug 10 2016 sebix+novell.com@sebix.at
- inital package
